# Coursebox DTU
DTU course management software.

## Installation
```terminal
pip install coursebox
```
## What it can do 
 - Single semester-dependent configuration file
 - Integrates with DTU Inside/DTU Learn
 - Distribution/evalauation of project reports in Learn-compatible format
 - Quiz-generation in DTU Learn/Beamer friendly format
 - Automatic website/syllabus generation 
 - Automatic generation of lectures handouts/exercises (you don't have to track dynamic content like dates/lecture titles; it is all in the configuration)
 - Easy compilation to 2/5 day formats (Continuous education)

## Usage
Coursebox requires a specific directory structure. It is easier to start with an existing course and adapt to your needs. Please contact me at tuhe@dtu.dk for more information.

## Citing
```bibtex
@online{coursebox,
	title={Coursebox (0.1.1): \texttt{pip install coursebox}},
	url={https://lab.compute.dtu.dk/tuhe/coursebox},
	urldate = {2021-09-07}, 
	month={9},
	publisher={Technical University of Denmark (DTU)},
	author={Tue Herlau},
	year={2021},
}
```